@@ -1,4 +1,4 @@
-# $Id: Title.pm,v 1.56 2006/08/16 19:34:38 joern Exp $
+# $Id: Title.pm 2397 2010-03-06 13:06:33Z joern $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2006 Jrn Reder <joern AT zyn.de>.
@@ -190,8 +190,12 @@ sub get_transcode_command {
     # no preview in cluster mode
     $command =~ s/-J\s+preview=[^\s]+//;
 
-    # add -S and -W options for chunk selection
-    $command .= " -S $psu -W $chunk,$chunk_cnt,$nav_file";
+    # add -S and -W options for chunk selection (dont' just append,
+    # because the transcode command probably got appended some
+    # additional shell commands - e.g. h264 log copy stuff)
+    $command =~
+        s{ (execflow.*?transcode) }
+         { $1 -S $psu -W $chunk,$chunk_cnt,$nav_file };
 
     # sorry, can't remember why I do that...
     $command =~ s/-M 2//;
@@ -214,9 +218,18 @@ sub get_transcode_audio_command {
     my $command = $self->SUPER::get_transcode_audio_command(@_);
     $command =~ s/\s+&& echo EXECFLOW_OK//;
 
-    $command .= " -S DVDRIP_JOB_PSU"
-        . " -W DVDRIP_JOB_CHUNK_CNT,DVDRIP_JOB_CHUNK_CNT,"
-        . $self->vob_nav_file;
+    if ( $self->version("transcode") >= 10100 ) {
+        $command .=
+              " --psu_mode --no_split"
+            . " --psu_chunks DVDRIP_JOB_PSU-DVDRIP_JOB_ADD_ONE_PSU"
+            . " --nav_seek ".$self->vob_nav_file;
+    }
+    else {
+        $command .=
+              " -S DVDRIP_JOB_PSU"
+            . " -W DVDRIP_JOB_CHUNK_CNT,DVDRIP_JOB_CHUNK_CNT,"
+            . $self->vob_nav_file;
+    }
 
     $command .= " && echo EXECFLOW_OK";
 
@@ -300,11 +313,14 @@ sub get_merge_video_audio_command {
         if $self->tc_nice =~ /\S/;
 
     my $command = "mkdir -m 0775 -p '$audio_video_psu_dir' && "
-        . "${nice}execflow avimerge -i $avi_chunks_dir/*"
-        . " -o $audio_video_psu_file ";
+        . "${nice}execflow avimerge -o $audio_video_psu_file";
 
     $command .= " -p $audio_psu_file " if !$self->is_ogg;
 
+    #-- -i *always* at the end! At some time avimerge's cmd line
+    #-- parser was messed up...
+    $command .= " -i $avi_chunks_dir/*";
+
     $command .= " && rm $avi_chunks_dir/*"
         if $self->with_cleanup;
 
