@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.67 2006/08/20 10:56:01 joern Exp $
+# $Id: Config.pm 2376 2009-02-22 18:49:03Z joern $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2006 Jrn Reder <joern AT zyn.de>.
@@ -10,6 +10,7 @@
 
 package Video::DVDRip::Config;
 use Locale::TextDomain qw (video.dvdrip);
+use POSIX qw(locale_h);
 
 use base Video::DVDRip::Base;
 
@@ -193,11 +194,11 @@ my %CONFIG_PARAMETER = (
     dvd_device => {
         label => __ "Default DVD device",
         type  => 'file',
-        value => "",
+        value => "/dev/cd0c",
         dvd_button => 1,
     },
     selected_dvd_device => {
-        value   => "/dev/dvd",
+        value   => "/dev/cd0c",
     },
     eject_command => {
         label => __ "Eject Command",
@@ -253,7 +254,7 @@ my %CONFIG_PARAMETER = (
         label => __ "OGG file extension",
         type  => 'string',
         value => 'ogm',
-        presets => [ 'ogg', 'ogm', ],
+        presets => [ 'ogg', 'ogm', 'ogv' ],
     },
     cluster_master_local => {
         label => __ "Start cluster control daemon locally",
@@ -306,6 +307,12 @@ my %CONFIG_PARAMETER = (
             [ 0       => __"Don't grab subtitles" ],
         ],
     },
+    default_preset => {
+        label   => __"Default Clip & Zoom preset",
+        type    => "popup",
+        value   => "auto_medium_fast",
+        presets => [],
+    },
     preferred_lang => {
         label   => __ "Preferred language",
         type    => 'popup',
@@ -325,6 +332,16 @@ my %CONFIG_PARAMETER = (
         chained => 1,
         avail_method => "check_nptl_workaround_possible",
     },
+    small_screen => {
+        label   => __ "Optimize layout for small screens",
+        type    => "switch",
+        value   => get_default_small_screen_value(),
+        tooltip =>
+            __ "With this option the dvd::rip GUI may be tweaked "
+              ."to fit even on small screens by adding scrollbars "
+              ."to the notebook pages. dvd::rip needs to be restarted "
+              ."to take effect"
+    },
 );
 
 my @CONFIG_ORDER = (
@@ -332,7 +349,7 @@ my @CONFIG_ORDER = (
         qw(
             dvd_device
             base_project_dir   dvdrip_files_dir
-            preferred_lang
+            preferred_lang     small_screen
             )
     ],
     __ "Commands" => [
@@ -353,6 +370,7 @@ my @CONFIG_ORDER = (
             default_container
             ogg_file_ext
             default_bpp
+            default_preset
             default_subtitle_grab
             workaround_nptl_bugs nptl_ld_assume_kernel
             )
@@ -363,13 +381,11 @@ sub config_definition { \%CONFIG_PARAMETER }
 
 sub new {
     my $type             = shift;
-    my %config_parameter = %CONFIG_PARAMETER;
-    my @config_order     = @CONFIG_ORDER;
 
     my @presets = (
         Video::DVDRip::Preset->new(
             name              => "nopreset",
-            title             => __ "- No Modifications -",
+            title             => __ "- No Modifications (anamorph) -",
             tc_clip1_top      => 0,
             tc_clip1_bottom   => 0,
             tc_clip1_left     => 0,
@@ -383,6 +399,11 @@ sub new {
             tc_fast_resize    => 0,
             tc_fast_bisection => 0,
         ),
+        Video::DVDRip::Preset->new(
+            name           => "auto_clip",
+            title          => __ "Autoadjust, Clipping only (anamorph)",
+            auto_clip      => 1,
+        ),
         Video::DVDRip::Preset->new(
             name           => "auto_big",
             title          => __ "Autoadjust, Big Frame Size, HQ Resize",
@@ -619,6 +640,16 @@ sub new {
         ),
     );
 
+    my $default_presets_lref = $CONFIG_PARAMETER{"default_preset"}->{presets};
+    
+    foreach my $preset ( @presets ) {
+        push @{$default_presets_lref}, 
+            [ $preset->name, $preset->title ];
+    }
+
+    my %config_parameter = %CONFIG_PARAMETER;
+    my @config_order     = @CONFIG_ORDER;
+
     my $self = {
         config  => \%config_parameter,
         order   => \@config_order,
@@ -649,7 +680,7 @@ sub init_settings {
     my $self = shift;
     
     if ( $self->get_value("dvd_device") eq "" ) {
-        $self->set_value( dvd_device => ($self->get_first_dvd_device || "/dev/dvd") );
+        $self->set_value( dvd_device => ($self->get_first_dvd_device || "/dev/cd0c") );
         $self->save;
     }
     
@@ -729,7 +760,7 @@ sub save {
     my $fh = FileHandle->new;
 
     open( $fh, "> $filename" ) or die "can't write $filename";
-    print $fh q{# $Id: Config.pm,v 1.67 2006/08/20 10:56:01 joern Exp $},
+    print $fh q{# $Id: Config.pm 2376 2009-02-22 18:49:03Z joern $},
         "\n";
     print $fh
         "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
@@ -992,4 +1023,10 @@ sub check_nptl_workaround_possible {
     return $check =~ /NPTL_OK/;
 }
 
+sub get_default_small_screen_value {
+    my $root_info = qx[xwininfo -root];
+    my ($width, $height) = $root_info =~ /Width:\s+(\d+).*?Height:\s+(\d+)/si;
+    return $height < 1024;
+}
+
 1;
