@@ -1,4 +1,4 @@
-# $Id: Title.pm,v 1.24 2006/08/18 21:51:16 joern Exp $
+# $Id: Title.pm 2344 2007-08-09 21:37:41Z joern $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2006 Jrn Reder <joern AT zyn.de>.
@@ -36,6 +36,7 @@ sub build_factory {
     my $context = $self->get_context;
 
     return Gtk2::Ex::FormFactory::VBox->new(
+        $self->get_optimum_screen_size_options("page"),
         title       => '[gtk-cdrom]'.__"RIP Title",
         object      => "project",
         active_cond => sub {
@@ -430,11 +431,9 @@ sub view_title {
 sub eject_dvd {
     my $self = shift;
 
-    my $title = $self->selected_title;
-
-    my $command
-        = $self->config('eject_command') . " " .
-            $title->project->dvd_device;
+    my $dev = $self->project->dvd_device;
+    $dev =~ s/^\/dev\/(cd[0-9])[a-p]/\1/;
+    my $command = $self->config('eject_command') . " " . $dev;
 
     system("$command &");
 
@@ -444,10 +443,9 @@ sub eject_dvd {
 sub insert_dvd {
     my $self = shift;
 
-    my $title = $self->selected_title;
-
-    my $command = $self->config('eject_command') . " -t "
-        . $title->project->dvd_device;
+    my $dev = $self->project->dvd_device;
+    $dev =~ s/^\/dev\/(cd[0-9])[a-p]/\1/;
+    my $command = $self->config('eject_command') . " -t " . $dev;
 
     system("$command &");
 
