@@ -1,4 +1,4 @@
-# $Id: JobPlanner.pm,v 1.14.2.3 2007/04/13 11:28:55 joern Exp $
+# $Id: JobPlanner.pm 2391 2009-12-19 13:34:55Z joern $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2006 Jrn Reder <joern AT zyn.de>.
@@ -257,7 +257,6 @@ sub build_rip_job {
         name                => "rip_and_preview",
         title               => __"Rip selected title(s) / chapter(s)",
         jobs                => \@jobs,
-        fails_with_members  => 1,
         stop_on_failure     => 0,
         post_callbacks      => sub { $self->get_project->backup_copy },
     );
@@ -403,16 +402,18 @@ sub analyze_rip {
 
         $job->frontend_signal("toc_info_changed");
 
-	if ( $disc_frames < $title_frames - 500 ) {
-		$job->set_error_message (
+	if ( $disc_frames / $title_frames < 0.99 ) {
+
+        my $message = 
                     __x("It seems that transcode ripping stopped short.\n".
 			"The movie has {title_frames} frames, but only {disc_frames}\n".
 			"were ripped. This is most likely a problem with your\n".
 			"transcode/libdvdread installation, resp. a problem with\n".
 			"this specific DVD.",
                         title_frames => $title_frames,
-                        disc_frames  => $disc_frames)
-		);
+                        disc_frames  => $disc_frames);
+            
+  		$job->set_warning_message ($message);
 	}
     }
 
@@ -460,7 +461,7 @@ sub build_grab_preview_frame_job {
     if ( ( $title->project->rip_mode ne 'rip' ||
            !$title->has_vob_nav_file ||
             $title->tc_force_slow_grabbing )
-          and not $self->exists("ffmpeg") ) {
+          and not $self->has("ffmpeg") ) {
         $progress_ips = __"fps";
         $progress_max = $title->preview_frame_nr;
         $slow_mode    = 1;
@@ -498,7 +499,7 @@ sub build_grab_preview_frame_job {
                     );
                 }
             }
-            if ( $self->exists("ffmpeg") and $buffer =~ /frame=\s*1.*?q\s*=/ ) {
+            if ( $self->has("ffmpeg") and $buffer =~ /frame=\s*1.*?q\s*=/ ) {
                 $got_frame_with_ffmpeg = 1;
             }
         },
@@ -513,7 +514,7 @@ sub build_grab_preview_frame_job {
         },
         post_callbacks => sub {
             my ($job) = @_;
-            if ( $self->exists("ffmpeg") and not $got_frame_with_ffmpeg ) {
+            if ( $self->has("ffmpeg") and not $got_frame_with_ffmpeg ) {
                 $job->set_error_message (
                     __ ("transcode can't find this frame. ").
                     __ ("Try a lower frame number. ").
@@ -730,7 +731,6 @@ sub build_transcode_job {
         title               => __"Transcode multiple titles",
         jobs                => \@title_jobs,
         parallel            => 0,
-        fails_with_members  => 1,
         stop_on_failure     => 0,
     );
 }
@@ -1076,7 +1076,14 @@ sub get_transcode_progress_parser {
         return sub {
             my ($job, $buffer) = @_;
             if ( $buffer =~ /frame=(\d+)/ ) {
-                $job->set_progress_cnt($1);
+                my $frame = $1;
+                $job->set_progress_cnt($frame);
+                if ( $buffer =~ /first=(\d+)/ ) {
+                    $job->set_progress_cnt($frame-$1);
+                }
+            }
+            if ( $buffer =~ /last=(\d+)/ ) {
+                $job->set_progress_max($1);
             }
             1;
         };
